@@ -623,7 +623,6 @@ class EnDS(object):
         out_file = os.path.join(t_d,"dsi_sim_vals.csv")
         ins_file = out_file + ".ins"
         sdf = pd.read_csv(out_file,index_col=0)
-        print(sdf)
         with open(ins_file,'w') as f:
             f.write("pif ~\n")
             f.write("l1\n")
@@ -648,7 +647,6 @@ class EnDS(object):
             par.loc[pname, "parlbnd"] = pval - 1000
 
         obs = pst.observation_data
-        print(obs)
         org_obs = self.pst.observation_data
         for col in org_obs.columns:
             obs.loc[org_obs.obsnme,col] = org_obs.loc[:,col]
