@@ -773,7 +773,8 @@ class ObservationEnsemble(Ensemble):
             warnings.warn("ObservationEnsemble.from_gaussian_draw(): all zero weights",PyemuWarning)
         # only draw for non-zero weights, get a new cov
         if not fill:
-            nz_cov = cov.get(pst.nnz_obs_names)
+            names = set(pst.nnz_obs_names).intersection(set(cov.row_names))
+            nz_cov = cov.get(list(names))
         else:
             nz_cov = cov.copy()
 
@@ -1175,7 +1176,7 @@ class ParameterEnsemble(Ensemble):
         # gaussian
         pes = []
         if len(how_groups["gaussian"]) > 0:
-            gset = set(how_groups["gaussian"])
+            gset = how_groups["gaussian"]
             par_gaussian = par_org.loc[gset, :]
             # par_gaussian.sort_values(by="parnme", inplace=True)
             par_gaussian.sort_index(inplace=True)
@@ -1184,7 +1185,7 @@ class ParameterEnsemble(Ensemble):
             if cov is not None:
                 cset = set(cov.row_names)
                 # gset = set(how_groups["gaussian"])
-                diff = gset.difference(cset)
+                diff = set(gset).difference(cset)
                 assert len(diff) == 0, (
                     "ParameterEnsemble.from_mixed_draws() error: the 'cov' is not compatible with "
                     + " the parameters listed as 'gaussian' in how_dict, the following are not in the cov:{0}".format(
@@ -1226,7 +1227,7 @@ class ParameterEnsemble(Ensemble):
                 df.loc[:, p] = v
 
         for pe in pes:
-            df.loc[pe.index, pe.columns] = pe
+            df.loc[pe.index, pe.columns] = pe._df
 
         # this dropna covers both "fill" and "partial"
         df = df.dropna(axis=1)
@@ -1272,7 +1273,7 @@ class ParameterEnsemble(Ensemble):
             # check for scale differences - I don't who is dumb enough
             # to change scale between par files and pst...
             diff = df.scale - pst.parameter_data.scale
-            if diff.apply(np.abs).sum() > 0.0:
+            if diff.abs().sum() > 0.0:
                 warnings.warn(
                     "differences in scale detected, applying scale in par file",
                     PyemuWarning,
@@ -1545,7 +1546,7 @@ class ParameterEnsemble(Ensemble):
         else:
             raise Exception(
                 "unrecognized enforce_bounds arg:"
-                + "{0}, should be 'reset' or 'drop'".format(enforce_bounds)
+                + "{0}, should be 'reset' or 'drop'".format(how)
             )
 
     def _enforce_scale(self, bound_tol):
@@ -1604,6 +1605,7 @@ class ParameterEnsemble(Ensemble):
 
             if lbnd_facs.shape[0] > 0:
                 lmin = lbnd_facs.min()
+                # print(lbnd_facs)
                 lmin_idx = lbnd_facs.idxmin()
                 print(
                     "enforce_scale lbnd controlling parameter, scale factor, "
