@@ -788,10 +788,10 @@ class OrdinaryKrige(object):
             warnings.warn(
                 "duplicates detected in point_data..attempting to rectify", PyemuWarning
             )
-            ux_std = point_data.groupby(point_data.name).std()["x"]
+            ux_std = point_data.groupby(point_data.name).x.std()
             if ux_std.max() > 0.0:
                 raise Exception("duplicate point_info entries with different x values")
-            uy_std = point_data.groupby(point_data.name).std()["y"]
+            uy_std = point_data.groupby(point_data.name).y.std()
             if uy_std.max() > 0.0:
                 raise Exception("duplicate point_info entries with different y values")
 
@@ -1291,13 +1291,14 @@ class OrdinaryKrige(object):
                 continue
 
             # only the maxpts_interp points
-            dist = dist.iloc[:maxpts_interp].apply(np.sqrt)
-            pt_names = dist.index.values
+            pt_names = dist.index.values[:maxpts_interp]
+            dist = np.sqrt(dist.values[:maxpts_interp])
+            
             # if one of the points is super close, just use it and skip
             if dist.min() <= EPSILON:
                 ifacts.append([1.0])
                 idist.append([EPSILON])
-                inames.append([dist.idxmin()])
+                inames.append([pt_names[dist.argmin()]])
                 err_var.append(self.geostruct.nugget)
                 continue
             # if verbose == 2:
@@ -1356,14 +1357,15 @@ class OrdinaryKrige(object):
 
             err_var.append(
                 float(
-                    sill
-                    + facs[-1]
-                    - sum([f * c for f, c in zip(facs[:-1], interp_cov)])
+                    (sill
+                     + facs[-1]
+                     - sum([f * c for f, c in zip(facs[:-1], interp_cov)])
+                     ).squeeze()
                 )
             )
             inames.append(pt_names)
 
-            idist.append(dist.values)
+            idist.append(dist)
             ifacts.append(facs[:-1, 0])
             # if verbose == 2:
             #     td = (datetime.now()-start).total_seconds()
@@ -1382,7 +1384,7 @@ class OrdinaryKrige(object):
             if self.interp_data is None:
                 self.interp_data = df
             else:
-                self.interp_data = self.interp_data.append(df)
+                self.interp_data = pd.concat([self.interp_data, df])
         # correct for negative kriging factors, if requested
         if remove_negative_factors == True:
             self._remove_neg_factors()
@@ -1574,9 +1576,10 @@ class OrdinaryKrige(object):
 
             err_var[idx] = [
                 float(
-                    sill
-                    + facs[-1]
-                    - sum([f * c for f, c in zip(facs[:-1], interp_cov)])
+                    (sill
+                     + facs[-1]
+                     - sum([f * c for f, c in zip(facs[:-1], interp_cov)])
+                     ).squeeze()
                 )
             ]
             inames[idx] = [pt_names.tolist()]
